@@ -26,10 +26,10 @@
 #define MIN(x,y) (((x)<(y))?(x):(y))
 
 #define CAFILE "ca.pem"
-#define CERT_URL "pkcs11:manufacturer=EnterSafe;object=Certificate" \
-  ";id=db:5b:3e:b5:72:33:92:99:18:ed:bb:eb:74:68:31:bd:b2:23:67:26"
-#define KEY_URL "pkcs11:manufacturer=EnterSafe;object=Certificate" \
-  ";id=db:5b:3e:b5:72:33:92:99:18:ed:bb:eb:74:68:31:bd:b2:23:67:26"
+#define KEY_URL "pkcs11:manufacturer=SomeManufacturer;object=Private%20Key" \
+  ";objecttype=private;id=db:5b:3e:b5:72:33"
+#define CERT_URL "pkcs11:manufacturer=SomeManufacturer;object=Certificate;" \
+  "objecttype=cert;id=db:5b:3e:b5:72:33"
 
 extern int tcp_connect (void);
 extern void tcp_close (int sd);
