@@ -520,20 +520,26 @@ gnutls_priority_set (gnutls_session_t session, gnutls_priority_t priority)
  *
  * "%COMPAT" will enable compatibility features for a server.
  *
- * "%DISABLE_SAFE_RENEGOTIATION" will disable safe renegotiation completely. Do not use
- * unless you know what you are doing. Testing purposes only.
+ * "%DISABLE_SAFE_RENEGOTIATION" will disable safe renegotiation
+ * completely.  Do not use unless you know what you are doing.
+ * Testing purposes only.
  *
- * "%UNSAFE_RENEGOTIATION" will allow unsafe renegotiation (this is now
- * the default for clients, but will change once more servers support the safe renegotiation
- * TLS fix).
+ * "%UNSAFE_RENEGOTIATION" will allow handshakes and rehandshakes
+ * without the safe renegotiation extension.  Note that for clients
+ * this mode is insecure (you may be under attack), and for servers it
+ * will allow insecure clients to connect (which could be fooled by an
+ * attacker).  Do not use unless you know what you are doing and want
+ * maximum compatibility.
  *
- * "%PARTIAL_SAFE_RENEGOTIATION" In server side it will enable safe renegotiation
- * and will protect all clients from known attacks, but will not prevent insecure clients
- * from connecting. In client side it will disallow from renegotiating with an insecure server
- * but will not prevent connecting to one (this leaves the client vulnerable to attacks).
+ * "%PARTIAL_RENEGOTIATION" will allow initial handshakes to proceed,
+ * but not rehandshakes.  This leaves the client vulnerable to attack,
+ * and servers will be compatible with non-upgraded clients for
+ * initial handshakes.  This is currently the default for clients and
+ * servers, for compatibility reasons.
  *
- * "%SAFE_RENEGOTIATION" will enforce safe renegotiation. Clients and Servers will refuse
- * to talk to an insecure peer.
+ * "%SAFE_RENEGOTIATION" will enforce safe renegotiation.  Clients and
+ * servers will refuse to talk to an insecure peer.  Currently this
+ * causes operability problems, but is required for full protection.
  *
  * "%SSL3_RECORD_VERSION" will use SSL3.0 record version in client hello.
  *
@@ -546,7 +552,9 @@ gnutls_priority_set (gnutls_session_t session, gnutls_priority_t priority)
  * To avoid collisions in order to specify a compression algorithm in
  * this string you have to prefix it with "COMP-", protocol versions
  * with "VERS-", signature algorithms with "SIGN-" and certificate types with "CTYPE-". All other
- * algorithms don't need a prefix.
+ * algorithms don't need a prefix. The keywords "SIGN-ALL", "CTYPE-ALL", "COMP-ALL",
+ * and "VERS-TLS-ALL"  can be used to add all the support signature types, certificate
+ * types, compression methods and supported TLS version numbers.
  *
  * Examples:
  * "NORMAL:!AES-128-CBC" means normal ciphers except for AES-128.
@@ -554,7 +562,7 @@ gnutls_priority_set (gnutls_session_t session, gnutls_priority_t priority)
  * "EXPORT:!VERS-TLS1.0:+COMP-DEFLATE" means that export ciphers are
  * enabled, TLS 1.0 is disabled, and libz compression enabled.
  *
- * "NONE:+VERS-TLS1.0:+AES-128-CBC:+RSA:+SHA1:+COMP-NULL:+SIGN-RSA-SHA1", "NORMAL",
+ * "NONE:+VERS-TLS-ALL:+AES-128-CBC:+RSA:+SHA1:+COMP-NULL:+SIGN-RSA-SHA1", "NORMAL",
  * "%COMPAT".
  *
  * Returns: On syntax error %GNUTLS_E_INVALID_REQUEST is returned,
@@ -674,39 +682,67 @@ gnutls_priority_init (gnutls_priority_t * priority_cache,
 	    fn (&(*priority_cache)->kx, algo);
 	  else if (strncasecmp (&broken_list[i][1], "VERS-", 5) == 0)
 	    {
-	      if ((algo =
-		   gnutls_protocol_get_id (&broken_list[i][6])) !=
-		  GNUTLS_VERSION_UNKNOWN)
-		fn (&(*priority_cache)->protocol, algo);
-	      else
-		goto error;
+	      if (strncasecmp (&broken_list[i][1], "VERS-TLS-ALL", 12) == 0)
+	        {
+	          _set_priority (&(*priority_cache)->protocol, protocol_priority);
+	        }
+	      else 
+	        {
+  	          if ((algo =
+		       gnutls_protocol_get_id (&broken_list[i][6])) !=
+		      GNUTLS_VERSION_UNKNOWN)
+                    fn (&(*priority_cache)->protocol, algo);
+                  else
+		    goto error;
+                }
 	    }			/* now check if the element is something like -ALGO */
 	  else if (strncasecmp (&broken_list[i][1], "COMP-", 5) == 0)
 	    {
-	      if ((algo =
-		   gnutls_compression_get_id (&broken_list[i][6])) !=
-		  GNUTLS_COMP_UNKNOWN)
-		fn (&(*priority_cache)->compression, algo);
-	      else
-		goto error;
+	      if (strncasecmp (&broken_list[i][1], "COMP-ALL", 8) == 0)
+	        {
+	          _set_priority (&(*priority_cache)->compression, comp_priority);
+	        }
+	      else 
+	        {
+	          if ((algo =
+		       gnutls_compression_get_id (&broken_list[i][6])) !=
+		       GNUTLS_COMP_UNKNOWN)
+                    fn (&(*priority_cache)->compression, algo);
+                  else
+                    goto error;
+                }
 	    }			/* now check if the element is something like -ALGO */
 	  else if (strncasecmp (&broken_list[i][1], "CTYPE-", 6) == 0)
 	    {
-	      if ((algo =
-		   gnutls_certificate_type_get_id (&broken_list[i][7])) !=
-		  GNUTLS_CRT_UNKNOWN)
-		fn (&(*priority_cache)->cert_type, algo);
-	      else
-		goto error;
+	      if (strncasecmp (&broken_list[i][1], "CTYPE-ALL", 9) == 0)
+	        {
+	          _set_priority (&(*priority_cache)->cert_type, cert_type_priority);
+	        }
+	      else 
+	        {
+	          if ((algo =
+		       gnutls_certificate_type_get_id (&broken_list[i][7])) !=
+		       GNUTLS_CRT_UNKNOWN)
+                    fn (&(*priority_cache)->cert_type, algo);
+                  else
+                    goto error;
+                }
 	    }			/* now check if the element is something like -ALGO */
 	  else if (strncasecmp (&broken_list[i][1], "SIGN-", 5) == 0)
 	    {
-	      if ((algo =
-		   gnutls_sign_get_id (&broken_list[i][6])) !=
-		  GNUTLS_SIGN_UNKNOWN)
-		fn (&(*priority_cache)->sign_algo, algo);
-	      else
-		goto error;
+	      if (strncasecmp (&broken_list[i][1], "SIGN-ALL", 8) == 0)
+	        {
+	          _set_priority (&(*priority_cache)->sign_algo, sign_priority_default);
+	        }
+	      else 
+	        {
+	          if ((algo =
+                      gnutls_sign_get_id (&broken_list[i][6])) !=
+                      GNUTLS_SIGN_UNKNOWN)
+    		    fn (&(*priority_cache)->sign_algo, algo);
+                  else
+                    goto error;
+                }
 	    }			/* now check if the element is something like -ALGO */
 	  else
 	    goto error;
