@@ -35,19 +35,21 @@
 #include <x509_int.h>
 #include <openpgp/openpgp_int.h>
 
-struct gnutls_privkey_st {
-	gnutls_privkey_type_t type;
-	gnutls_pk_algorithm_t pk_algorithm;
+struct gnutls_privkey_st
+{
+  gnutls_privkey_type_t type;
+  gnutls_pk_algorithm_t pk_algorithm;
 
-	union {
-		gnutls_x509_privkey_t x509;
-		gnutls_pkcs11_privkey_t pkcs11;
+  union
+  {
+    gnutls_x509_privkey_t x509;
+    gnutls_pkcs11_privkey_t pkcs11;
 #ifdef ENABLE_OPENPGP
-		gnutls_openpgp_privkey_t openpgp;
+    gnutls_openpgp_privkey_t openpgp;
 #endif
-	} key;
+  } key;
 
-	unsigned int flags;
+  unsigned int flags;
 };
 
 /**
@@ -60,9 +62,10 @@ struct gnutls_privkey_st {
  * Returns: a member of the #gnutls_privkey_type_t enumeration on
  *   success, or a negative value on error.
  **/
-gnutls_privkey_type_t gnutls_privkey_get_type(gnutls_privkey_t key)
+gnutls_privkey_type_t
+gnutls_privkey_get_type (gnutls_privkey_t key)
 {
-	return key->type;
+  return key->type;
 }
 
 /**
@@ -77,30 +80,25 @@ gnutls_privkey_type_t gnutls_privkey_get_type(gnutls_privkey_t key)
  * Returns: a member of the #gnutls_pk_algorithm_t enumeration on
  *   success, or a negative value on error.
  **/
-int gnutls_privkey_get_pk_algorithm(gnutls_privkey_t key,
-				    unsigned int *bits)
+int
+gnutls_privkey_get_pk_algorithm (gnutls_privkey_t key, unsigned int *bits)
 {
-	switch (key->type) {
+  switch (key->type)
+    {
 #ifdef ENABLE_OPENPGP
-	case GNUTLS_PRIVKEY_OPENPGP:
-		return gnutls_openpgp_privkey_get_pk_algorithm(key->key.
-							       openpgp,
-							       bits);
+    case GNUTLS_PRIVKEY_OPENPGP:
+      return gnutls_openpgp_privkey_get_pk_algorithm (key->key.openpgp, bits);
 #endif
-	case GNUTLS_PRIVKEY_PKCS11:
-		return gnutls_pkcs11_privkey_get_pk_algorithm(key->key.
-							      pkcs11,
-							      bits);
-	case GNUTLS_PRIVKEY_X509:
-		if (bits)
-			*bits =
-			    _gnutls_mpi_get_nbits(key->key.x509->
-						  params[0]);
-		return gnutls_x509_privkey_get_pk_algorithm(key->key.x509);
-	default:
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    case GNUTLS_PRIVKEY_PKCS11:
+      return gnutls_pkcs11_privkey_get_pk_algorithm (key->key.pkcs11, bits);
+    case GNUTLS_PRIVKEY_X509:
+      if (bits)
+	*bits = _gnutls_mpi_get_nbits (key->key.x509->params[0]);
+      return gnutls_x509_privkey_get_pk_algorithm (key->key.x509);
+    default:
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
 
 }
 
@@ -113,15 +111,17 @@ int gnutls_privkey_get_pk_algorithm(gnutls_privkey_t key,
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  *   negative error value.
  **/
-int gnutls_privkey_init(gnutls_privkey_t * key)
+int
+gnutls_privkey_init (gnutls_privkey_t * key)
 {
-	*key = gnutls_calloc(1, sizeof(struct gnutls_privkey_st));
-	if (*key == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_MEMORY_ERROR;
-	}
+  *key = gnutls_calloc (1, sizeof (struct gnutls_privkey_st));
+  if (*key == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_MEMORY_ERROR;
+    }
 
-	return 0;
+  return 0;
 }
 
 /**
@@ -130,22 +130,22 @@ int gnutls_privkey_init(gnutls_privkey_t * key)
  *
  * This function will deinitialize a private key structure.
  **/
-void gnutls_privkey_deinit(gnutls_privkey_t key)
+void
+gnutls_privkey_deinit (gnutls_privkey_t key)
 {
-	if (key->flags & GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE)
-		switch (key->type) {
+  if (key->flags & GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE)
+    switch (key->type)
+      {
 #ifdef ENABLE_OPENPGP
-		case GNUTLS_PRIVKEY_OPENPGP:
-			return gnutls_openpgp_privkey_deinit(key->key.
-							     openpgp);
+      case GNUTLS_PRIVKEY_OPENPGP:
+	return gnutls_openpgp_privkey_deinit (key->key.openpgp);
 #endif
-		case GNUTLS_PRIVKEY_PKCS11:
-			return gnutls_pkcs11_privkey_deinit(key->key.
-							    pkcs11);
-		case GNUTLS_PRIVKEY_X509:
-			return gnutls_x509_privkey_deinit(key->key.x509);
-		}
-	gnutls_free(key);
+      case GNUTLS_PRIVKEY_PKCS11:
+	return gnutls_pkcs11_privkey_deinit (key->key.pkcs11);
+      case GNUTLS_PRIVKEY_X509:
+	return gnutls_x509_privkey_deinit (key->key.x509);
+      }
+  gnutls_free (key);
 }
 
 /**
@@ -160,17 +160,16 @@ void gnutls_privkey_deinit(gnutls_privkey_t key)
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  *   negative error value.
  **/
-int gnutls_privkey_import_pkcs11(gnutls_privkey_t pkey,
-				 gnutls_pkcs11_privkey_t key,
-				 unsigned int flags)
+int
+gnutls_privkey_import_pkcs11 (gnutls_privkey_t pkey,
+			      gnutls_pkcs11_privkey_t key, unsigned int flags)
 {
-	pkey->key.pkcs11 = key;
-	pkey->type = GNUTLS_PRIVKEY_PKCS11;
-	pkey->pk_algorithm =
-	    gnutls_pkcs11_privkey_get_pk_algorithm(key, NULL);
-	pkey->flags = flags;
+  pkey->key.pkcs11 = key;
+  pkey->type = GNUTLS_PRIVKEY_PKCS11;
+  pkey->pk_algorithm = gnutls_pkcs11_privkey_get_pk_algorithm (key, NULL);
+  pkey->flags = flags;
 
-	return 0;
+  return 0;
 }
 
 /**
@@ -185,16 +184,16 @@ int gnutls_privkey_import_pkcs11(gnutls_privkey_t pkey,
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  *   negative error value.
  **/
-int gnutls_privkey_import_x509(gnutls_privkey_t pkey,
-			       gnutls_x509_privkey_t key,
-			       unsigned int flags)
+int
+gnutls_privkey_import_x509 (gnutls_privkey_t pkey,
+			    gnutls_x509_privkey_t key, unsigned int flags)
 {
-	pkey->key.x509 = key;
-	pkey->type = GNUTLS_PRIVKEY_X509;
-	pkey->pk_algorithm = gnutls_x509_privkey_get_pk_algorithm(key);
-	pkey->flags = flags;
+  pkey->key.x509 = key;
+  pkey->type = GNUTLS_PRIVKEY_X509;
+  pkey->pk_algorithm = gnutls_x509_privkey_get_pk_algorithm (key);
+  pkey->flags = flags;
 
-	return 0;
+  return 0;
 }
 
 #ifdef ENABLE_OPENPGP
@@ -210,17 +209,17 @@ int gnutls_privkey_import_x509(gnutls_privkey_t pkey,
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  *   negative error value.
  **/
-int gnutls_privkey_import_openpgp(gnutls_privkey_t pkey,
-				  gnutls_openpgp_privkey_t key,
-				  unsigned int flags)
+int
+gnutls_privkey_import_openpgp (gnutls_privkey_t pkey,
+			       gnutls_openpgp_privkey_t key,
+			       unsigned int flags)
 {
-	pkey->key.openpgp = key;
-	pkey->type = GNUTLS_PRIVKEY_OPENPGP;
-	pkey->pk_algorithm =
-	    gnutls_openpgp_privkey_get_pk_algorithm(key, NULL);
-	pkey->flags = flags;
+  pkey->key.openpgp = key;
+  pkey->type = GNUTLS_PRIVKEY_OPENPGP;
+  pkey->pk_algorithm = gnutls_openpgp_privkey_get_pk_algorithm (key, NULL);
+  pkey->flags = flags;
 
-	return 0;
+  return 0;
 }
 #endif
 
@@ -241,45 +240,49 @@ int gnutls_privkey_import_openpgp(gnutls_privkey_t pkey,
  * negative error value.
  **/
 int
-gnutls_privkey_sign_data(gnutls_privkey_t signer,
-			 gnutls_digest_algorithm_t hash,
-			 unsigned int flags,
-			 const gnutls_datum_t * data,
-			 gnutls_datum_t * signature)
+gnutls_privkey_sign_data (gnutls_privkey_t signer,
+			  gnutls_digest_algorithm_t hash,
+			  unsigned int flags,
+			  const gnutls_datum_t * data,
+			  gnutls_datum_t * signature)
 {
-	int ret;
-	gnutls_datum_t digest;
+  int ret;
+  gnutls_datum_t digest;
 
-	switch (signer->pk_algorithm) {
-	case GNUTLS_PK_RSA:
-		ret = pk_pkcs1_rsa_hash(hash, data, &digest);
-		if (ret < 0) {
-			gnutls_assert();
-			return ret;
-		}
-		break;
-	case GNUTLS_PK_DSA:
-		ret = pk_dsa_hash(hash, data, &digest);
-		if (ret < 0) {
-			gnutls_assert();
-			return ret;
-		}
-
-		break;
-	default:
-		gnutls_assert();
-		return GNUTLS_E_INTERNAL_ERROR;
+  switch (signer->pk_algorithm)
+    {
+    case GNUTLS_PK_RSA:
+      ret = pk_pkcs1_rsa_hash (hash, data, &digest);
+      if (ret < 0)
+	{
+	  gnutls_assert ();
+	  return ret;
+	}
+      break;
+    case GNUTLS_PK_DSA:
+      ret = pk_dsa_hash (hash, data, &digest);
+      if (ret < 0)
+	{
+	  gnutls_assert ();
+	  return ret;
 	}
 
-	ret = gnutls_privkey_sign_hash(signer, &digest, signature);
-	_gnutls_free_datum(&digest);
+      break;
+    default:
+      gnutls_assert ();
+      return GNUTLS_E_INTERNAL_ERROR;
+    }
 
-	if (ret < 0) {
-		gnutls_assert();
-		return ret;
-	}
+  ret = gnutls_privkey_sign_hash (signer, &digest, signature);
+  _gnutls_free_datum (&digest);
 
-	return 0;
+  if (ret < 0)
+    {
+      gnutls_assert ();
+      return ret;
+    }
+
+  return 0;
 }
 
 /**
@@ -294,26 +297,27 @@ gnutls_privkey_sign_data(gnutls_privkey_t signer,
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  * negative error value.
  **/
-int gnutls_privkey_sign_hash(gnutls_privkey_t key,
-			     const gnutls_datum_t * hash,
-			     gnutls_datum_t * signature)
+int
+gnutls_privkey_sign_hash (gnutls_privkey_t key,
+			  const gnutls_datum_t * hash,
+			  gnutls_datum_t * signature)
 {
-	switch (key->type) {
+  switch (key->type)
+    {
 #ifdef ENABLE_OPENPGP
-	case GNUTLS_PRIVKEY_OPENPGP:
-		return gnutls_openpgp_privkey_sign_hash(key->key.openpgp,
-							hash, signature);
+    case GNUTLS_PRIVKEY_OPENPGP:
+      return gnutls_openpgp_privkey_sign_hash (key->key.openpgp,
+					       hash, signature);
 #endif
-	case GNUTLS_PRIVKEY_PKCS11:
-		return gnutls_pkcs11_privkey_sign_hash(key->key.pkcs11,
-						       hash, signature);
-	case GNUTLS_PRIVKEY_X509:
-		return gnutls_x509_privkey_sign_hash(key->key.x509, hash,
-						     signature);
-	default:
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    case GNUTLS_PRIVKEY_PKCS11:
+      return gnutls_pkcs11_privkey_sign_hash (key->key.pkcs11,
+					      hash, signature);
+    case GNUTLS_PRIVKEY_X509:
+      return gnutls_x509_privkey_sign_hash (key->key.x509, hash, signature);
+    default:
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
 }
 
 /**
@@ -329,36 +333,35 @@ int gnutls_privkey_sign_hash(gnutls_privkey_t key,
  * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
  * negative error value.
  **/
-int gnutls_privkey_decrypt_data(gnutls_privkey_t key,
-				unsigned int flags,
-				const gnutls_datum_t * ciphertext,
-				gnutls_datum_t * plaintext)
+int
+gnutls_privkey_decrypt_data (gnutls_privkey_t key,
+			     unsigned int flags,
+			     const gnutls_datum_t * ciphertext,
+			     gnutls_datum_t * plaintext)
 {
-	if (key->pk_algorithm != GNUTLS_PK_RSA) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+  if (key->pk_algorithm != GNUTLS_PK_RSA)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	switch (key->type) {
+  switch (key->type)
+    {
 #ifdef ENABLE_OPENPGP
-	case GNUTLS_PRIVKEY_OPENPGP:
-		return gnutls_openpgp_privkey_decrypt_data(key->key.
-							   openpgp, flags,
-							   ciphertext,
-							   plaintext);
+    case GNUTLS_PRIVKEY_OPENPGP:
+      return gnutls_openpgp_privkey_decrypt_data (key->key.openpgp, flags,
+						  ciphertext, plaintext);
 #endif
-	case GNUTLS_PRIVKEY_X509:
-		return _gnutls_pkcs1_rsa_decrypt(plaintext, ciphertext,
-						 key->key.x509->params,
-						 key->key.x509->
-						 params_size, 2);
-	case GNUTLS_PRIVKEY_PKCS11:
-		return gnutls_pkcs11_privkey_decrypt_data(key->key.pkcs11,
-							  flags,
-							  ciphertext,
-							  plaintext);
-	default:
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    case GNUTLS_PRIVKEY_X509:
+      return _gnutls_pkcs1_rsa_decrypt (plaintext, ciphertext,
+					key->key.x509->params,
+					key->key.x509->params_size, 2);
+    case GNUTLS_PRIVKEY_PKCS11:
+      return gnutls_pkcs11_privkey_decrypt_data (key->key.pkcs11,
+						 flags,
+						 ciphertext, plaintext);
+    default:
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
 }
