@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2008, 2010 Free Software Foundation, Inc.
+ * Copyright (C) 2010 Free Software Foundation, Inc.
+ * Copyright (C) 2000, 2001, 2008 Niels Möller
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -22,7 +23,10 @@
  *
  */
 
-/* Here is the libgcrypt random generator layer.
+/* Here is the random generator layer. This code was based on the LSH 
+ * random generator (the trivia and device source functions for POSIX)
+ * and modified to fit gnutls' needs. Relicenced with permission. 
+ * Original author Niels Möller.
  */
 
 #include <gnutls_int.h>
@@ -151,6 +155,9 @@ wrap_nettle_rnd_deinit (void *ctx)
 #include <sys/time.h>
 #include <fcntl.h>
 #include <locks.h>
+#ifdef HAVE_GETRUSAGE
+# include <sys/resource.h>
+#endif
 #include "egd.h"
 
 #define DEVICE_READ_SIZE 16
